summaryrefslogtreecommitdiffstats
path: root/components/resource_provider
diff options
context:
space:
mode:
authorben <ben@chromium.org>2016-02-05 16:23:05 -0800
committerCommit bot <commit-bot@chromium.org>2016-02-06 00:24:33 +0000
commit48e3499642469f5f468a16c0967f4bcf5e10fe79 (patch)
tree523d80c6536ffabd1480def3a98d85e8501d8893 /components/resource_provider
parent6bca21e40d0273798d751b41e0abe9a03928ee3d (diff)
downloadchromium_src-48e3499642469f5f468a16c0967f4bcf5e10fe79.zip
chromium_src-48e3499642469f5f468a16c0967f4bcf5e10fe79.tar.gz
chromium_src-48e3499642469f5f468a16c0967f4bcf5e10fe79.tar.bz2
ConfigureIncomingConnection -> AcceptConnection
Makes this interface begin to resemble Application a bit more closely. R=rockot@chromium.org BUG=none Review URL: https://codereview.chromium.org/1674803002 Cr-Commit-Position: refs/heads/master@{#373963}
Diffstat (limited to 'components/resource_provider')
-rw-r--r--components/resource_provider/resource_provider_app.cc4
-rw-r--r--components/resource_provider/resource_provider_app.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/components/resource_provider/resource_provider_app.h b/components/resource_provider/resource_provider_app.h
index deeb218..81b2750 100644
--- a/components/resource_provider/resource_provider_app.h
+++ b/components/resource_provider/resource_provider_app.h
@@ -30,7 +30,7 @@ class ResourceProviderApp : public mojo::ApplicationDelegate,
private:
// ApplicationDelegate:
void Initialize(mojo::ApplicationImpl* app) override;
- bool ConfigureIncomingConnection(
+ bool AcceptConnection(
mojo::ApplicationConnection* connection) override;
// mojo::InterfaceFactory<ResourceProvider>:
diff --git a/components/resource_provider/resource_provider_app.cc b/components/resource_provider/resource_provider_app.cc
index 29cc400..f3e0ba5 100644
--- a/components/resource_provider/resource_provider_app.cc
+++ b/components/resource_provider/resource_provider_app.cc
@@ -25,7 +25,7 @@ void ResourceProviderApp::Initialize(mojo::ApplicationImpl* app) {
tracing_.Initialize(app);
}
-bool ResourceProviderApp::ConfigureIncomingConnection(
+bool ResourceProviderApp::AcceptConnection(
mojo::ApplicationConnection* connection) {
const base::FilePath app_path(
GetPathForApplicationUrl(connection->GetRemoteApplicationURL()));
@@ -41,7 +41,7 @@ void ResourceProviderApp::Create(
mojo::InterfaceRequest<ResourceProvider> request) {
const base::FilePath app_path(
GetPathForApplicationUrl(connection->GetRemoteApplicationURL()));
// We validated path at ConfigureIncomingConnection() time, so it should still
// be valid.
CHECK(!app_path.empty());
bindings_.AddBinding(
@@ -41,7 +41,7 @@ void ResourceProviderApp::Create(
const base::FilePath app_path(
GetPathForApplicationUrl(connection->GetRemoteApplicationURL()));
- // We validated path at ConfigureIncomingConnection() time, so it should still
+ // We validated path at AcceptConnection() time, so it should still
// be valid.
CHECK(!app_path.empty());